# pylint: disable=missing-docstring, too-few-public-methods

class Aaaa(object):
    pass
class Bbbb(object):
    pass
class Cccc(object):
    pass
class Dddd(object):
    pass
class Eeee(object):
    pass
class Ffff(object):
    pass
class Gggg(object):
    pass
class Hhhh(object):
    pass

class Iiii(Aaaa, Bbbb, Cccc, Dddd, Eeee, Ffff, Gggg, Hhhh): # [too-many-ancestors]
    pass

class Jjjj(Iiii): # [too-many-ancestors]
    pass



"""Checks import position rule"""
# pylint: disable=unused-import,relative-import,ungrouped-imports,import-error,no-name-in-module,relative-beyond-top-level,undefined-variable

import y

if x:
    import os



"""
Test for issue ##1139 - when CRLF newline characters are used,
\r is left in msg section. As a result, output line in cmdline
is overwritten with text after msg"""

# TODO Lorem ipsum dolor sit amet consectetur adipiscing elit  # [fixme]



# pylint: disable=missing-docstring, too-few-public-methods

class Aaaa(object): # [too-many-instance-attributes]

    def __init__(self):
        self.aaaa = 1
        self.bbbb = 2
        self.cccc = 3
        self.dddd = 4
        self.eeee = 5
        self.ffff = 6
        self.gggg = 7
        self.hhhh = 8
        self.iiii = 9
        self.jjjj = 10
        self._aaaa = 1
        self._bbbb = 2
        self._cccc = 3
        self._dddd = 4
        self._eeee = 5
        self._ffff = 6
        self._gggg = 7
        self._hhhh = 8
        self._iiii = 9
        self._jjjj = 10
        self.tomuch = None



# pylint: disable=missing-docstring, pointless-statement
from __future__ import print_function


def totoo():
 print('malindented') # [bad-indentation]

def tutuu():
    print('good indentation')

def titii():
     1  # and this. # [bad-indentation]

def tataa(kdict):
    for key in ['1', '2', '3']:
        key = key.lower()

        if key in kdict:
            del kdict[key]



# pylint: disable=missing-docstring

exec 'a = __revision__' # [exec-used]
VALUES = {}
exec 'a = 1' in VALUES # [exec-used]

exec 'a = 1' in globals() # [exec-used]

def func():
    exec 'b = 1' # [exec-used]



"""Checks import position rule"""
# pylint: disable=unused-import,relative-import,ungrouped-imports,import-error,no-name-in-module,relative-beyond-top-level,unused-variable
def method1():
    """Method 1"""
    import x



# pylint: disable=missing-docstring, no-staticmethod-decorator

class Abcd(object):

    def method1(self): # [bad-staticmethod-argument]
        pass

    method1 = staticmethod(method1)

    def method2(cls): # [bad-staticmethod-argument]
        pass

    method2 = staticmethod(method2)

    def __init__(self):
        pass



""" Testing with statements that use generators. This should not crash. """

class Base(object):
    """ Base class. """
    val = 0

    def gen(self):
        """ A generator. """
        yield self.val

    def fun(self):
        """ With statement using a generator. """
        with self.gen():  # [not-context-manager]
            pass
